@@ -1,4 +1,4 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -21,7 +21,6 @@ import java.io.IOException;
 import java.util.Comparator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
-
 import org.apache.commons.lang3.NotImplementedException;
 import org.apache.hadoop.fs.FSDataInputStream;
 import org.apache.hadoop.fs.FSDataOutputStream;
@@ -36,8 +35,8 @@ import org.apache.hadoop.hbase.client.TableDescriptor;
 import org.apache.hadoop.hbase.client.TableDescriptorBuilder;
 import org.apache.hadoop.hbase.exceptions.DeserializationException;
 import org.apache.hadoop.hbase.util.Bytes;
+import org.apache.hadoop.security.AccessControlException;
 import org.apache.yetus.audience.InterfaceAudience;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -45,31 +44,24 @@ import org.apache.hbase.thirdparty.com.google.common.annotations.VisibleForTesti
 import org.apache.hbase.thirdparty.com.google.common.primitives.Ints;
 
 /**
- *
- * COPIED (partially) from org.apache.hadoop.hbase.util.FSTableDescriptors
- * because the original class was tagged with @InterfaceAudience.Private.
- *
- * We only kept the public methods we are using in HBCK. Also removed the cache
- * and readonly features.
- *
- * Implementation of {@link TableDescriptors} that reads descriptors from the
- * passed filesystem.  It expects descriptors to be in a file in the
- * {@link #TABLEINFO_DIR} subdir of the table's directory in FS.
- * *
- * <p>Also has utility for keeping up the table descriptors tableinfo file.
- * The table schema file is kept in the {@link #TABLEINFO_DIR} subdir
- * of the table directory in the filesystem.
- * It has a {@link #TABLEINFO_FILE_PREFIX} and then a suffix that is the
- * edit sequenceid: e.g. <code>.tableinfo.0000000003</code>.  This sequenceid
- * is always increasing.  It starts at zero.  The table schema file with the
- * highest sequenceid has the most recent schema edit. Usually there is one file
- * only, the most recent but there may be short periods where there are more
- * than one file. Old files are eventually cleaned.  Presumption is that there
- * will not be lots of concurrent clients making table schema edits.  If so,
- * the below needs a bit of a reworking and perhaps some supporting api in hdfs.
+ * COPIED (partially) from org.apache.hadoop.hbase.util.FSTableDescriptors because the original
+ * class was tagged with @InterfaceAudience.Private. We only kept the public methods we are using in
+ * HBCK. Also removed the cache and readonly features. Implementation of {@link TableDescriptors}
+ * that reads descriptors from the passed filesystem. It expects descriptors to be in a file in the
+ * {@link #TABLEINFO_DIR} subdir of the table's directory in FS. *
+ * <p>
+ * Also has utility for keeping up the table descriptors tableinfo file. The table schema file is
+ * kept in the {@link #TABLEINFO_DIR} subdir of the table directory in the filesystem. It has a
+ * {@link #TABLEINFO_FILE_PREFIX} and then a suffix that is the edit sequenceid: e.g.
+ * <code>.tableinfo.0000000003</code>. This sequenceid is always increasing. It starts at zero. The
+ * table schema file with the highest sequenceid has the most recent schema edit. Usually there is
+ * one file only, the most recent but there may be short periods where there are more than one file.
+ * Old files are eventually cleaned. Presumption is that there will not be lots of concurrent
+ * clients making table schema edits. If so, the below needs a bit of a reworking and perhaps some
+ * supporting api in hdfs.
  */
 @InterfaceAudience.Private
-public class HBCKFsTableDescriptors  {
+public class HBCKFsTableDescriptors {
   private static final Logger LOG = LoggerFactory.getLogger(HBCKFsTableDescriptors.class);
   private final FileSystem fs;
   private final Path rootdir;
@@ -81,38 +73,31 @@ public class HBCKFsTableDescriptors  {
   static final String TABLEINFO_DIR = ".tabledesc";
   static final String TMP_DIR = ".tmp";
 
-
   public HBCKFsTableDescriptors(final FileSystem fs, final Path rootdir) {
     this.fs = fs;
     this.rootdir = rootdir;
   }
 
   /**
-   * Find the most current table info file for the table located in the given table directory.
-   *
-   * Looks within the {@link #TABLEINFO_DIR} subdirectory of the given directory for any table info
-   * files and takes the 'current' one - meaning the one with the highest sequence number if present
-   * or no sequence number at all if none exist (for backward compatibility from before there
-   * were sequence numbers).
-   *
+   * Find the most current table info file for the table located in the given table directory. Looks
+   * within the {@link #TABLEINFO_DIR} subdirectory of the given directory for any table info files
+   * and takes the 'current' one - meaning the one with the highest sequence number if present or no
+   * sequence number at all if none exist (for backward compatibility from before there were
+   * sequence numbers).
    * @return The file status of the current table info file or null if it does not exist
    * @throws IOException for IO errors
    */
-  public static FileStatus getTableInfoPath(FileSystem fs, Path tableDir)
-    throws IOException {
+  public static FileStatus getTableInfoPath(FileSystem fs, Path tableDir) throws IOException {
     return getTableInfoPath(fs, tableDir, false);
   }
 
   /**
-   * Find the most current table info file for the table in the given table directory.
-   *
-   * Looks within the {@link #TABLEINFO_DIR} subdirectory of the given directory for any table info
-   * files and takes the 'current' one - meaning the one with the highest sequence number if
-   * present or no sequence number at all if none exist (for backward compatibility from before
-   * there were sequence numbers).
-   * If there are multiple table info files found and removeOldFiles is true it also deletes the
-   * older files.
-   *
+   * Find the most current table info file for the table in the given table directory. Looks within
+   * the {@link #TABLEINFO_DIR} subdirectory of the given directory for any table info files and
+   * takes the 'current' one - meaning the one with the highest sequence number if present or no
+   * sequence number at all if none exist (for backward compatibility from before there were
+   * sequence numbers). If there are multiple table info files found and removeOldFiles is true it
+   * also deletes the older files.
    * @return The file status of the current table info file or null if none exist
    * @throws IOException for IO errors
    */
@@ -123,22 +108,18 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Find the most current table info file in the given directory
-   *
-   * Looks within the given directory for any table info files
-   * and takes the 'current' one - meaning the one with the highest sequence number if present
-   * or no sequence number at all if none exist (for backward compatibility from before there
-   * were sequence numbers).
-   * If there are multiple possible files found
-   * and the we're not in read only mode it also deletes the older files.
-   *
+   * Find the most current table info file in the given directory Looks within the given directory
+   * for any table info files and takes the 'current' one - meaning the one with the highest
+   * sequence number if present or no sequence number at all if none exist (for backward
+   * compatibility from before there were sequence numbers). If there are multiple possible files
+   * found and the we're not in read only mode it also deletes the older files.
    * @return The file status of the current table info file or null if it does not exist
    * @throws IOException for IO errors
    */
   // only visible for FSTableDescriptorMigrationToSubdir, can be removed with that
   static FileStatus getCurrentTableInfoStatus(FileSystem fs, Path dir, boolean removeOldFiles)
     throws IOException {
-    FileStatus [] status = HBCKFsUtils.listStatus(fs, dir, TABLEINFO_PATHFILTER);
+    FileStatus[] status = HBCKFsUtils.listStatus(fs, dir, TABLEINFO_PATHFILTER);
     if (status == null || status.length < 1) {
       return null;
     }
@@ -165,8 +146,7 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Compare {@link FileStatus} instances by {@link Path#getName()}. Returns in
-   * reverse order.
+   * Compare {@link FileStatus} instances by {@link Path#getName()}. Returns in reverse order.
    */
   @VisibleForTesting
   static final Comparator<FileStatus> TABLEINFO_FILESTATUS_COMPARATOR =
@@ -174,12 +154,14 @@ public class HBCKFsTableDescriptors  {
       @Override
       public int compare(FileStatus left, FileStatus right) {
         return right.compareTo(left);
-      }};
+      }
+    };
 
   /**
    * Return the table directory in HDFS
    */
-  @VisibleForTesting Path getTableDir(final TableName tableName) {
+  @VisibleForTesting
+  Path getTableDir(final TableName tableName) {
     return HBCKFsUtils.getTableDir(rootdir, tableName);
   }
 
@@ -188,41 +170,43 @@ public class HBCKFsTableDescriptors  {
     public boolean accept(Path p) {
       // Accept any file that starts with TABLEINFO_NAME
       return p.getName().startsWith(TABLEINFO_FILE_PREFIX);
-    }};
+    }
+  };
 
   /**
    * Width of the sequenceid that is a suffix on a tableinfo file.
    */
-  @VisibleForTesting static final int WIDTH_OF_SEQUENCE_ID = 10;
+  @VisibleForTesting
+  static final int WIDTH_OF_SEQUENCE_ID = 10;
 
   /*
    * @param number Number to use as suffix.
-   * @return Returns zero-prefixed decimal version of passed
-   * number (Does absolute in case number is negative).
+   * @return Returns zero-prefixed decimal version of passed number (Does absolute in case number is
+   * negative).
    */
   private static String formatTableInfoSequenceId(final int number) {
-    byte [] b = new byte[WIDTH_OF_SEQUENCE_ID];
+    byte[] b = new byte[WIDTH_OF_SEQUENCE_ID];
     int d = Math.abs(number);
     for (int i = b.length - 1; i >= 0; i--) {
-      b[i] = (byte)((d % 10) + '0');
+      b[i] = (byte) ((d % 10) + '0');
       d /= 10;
     }
     return Bytes.toString(b);
   }
 
   /**
-   * Regex to eat up sequenceid suffix on a .tableinfo file.
-   * Use regex because may encounter oldstyle .tableinfos where there is no
-   * sequenceid on the end.
+   * Regex to eat up sequenceid suffix and file size suffix on a .tableinfo file. Use regex because
+   * may encounter oldstyle .tableinfos where there is no sequenceid nor filesize at the end.
    */
-  private static final Pattern TABLEINFO_FILE_REGEX =
-    Pattern.compile(TABLEINFO_FILE_PREFIX + "(\\.([0-9]{" + WIDTH_OF_SEQUENCE_ID + "}))?$");
+  private static final Pattern TABLEINFO_FILE_REGEX = Pattern.compile(
+    TABLEINFO_FILE_PREFIX + "(\\.([0-9]{" + WIDTH_OF_SEQUENCE_ID + "}))?" + "(\\.([0-9]+))?$");
 
   /**
    * @param p Path to a <code>.tableinfo</code> file.
    * @return The current editid or 0 if none found.
    */
-  @VisibleForTesting static int getTableInfoSequenceId(final Path p) {
+  @VisibleForTesting
+  static int getTableInfoSequenceId(final Path p) {
     if (p == null) {
       return 0;
     }
@@ -241,24 +225,24 @@ public class HBCKFsTableDescriptors  {
    * @param sequenceid sequence id
    * @return Name of tableinfo file.
    */
-  @VisibleForTesting static String getTableInfoFileName(final int sequenceid) {
+  @VisibleForTesting
+  static String getTableInfoFileName(final int sequenceid) {
     return TABLEINFO_FILE_PREFIX + "." + formatTableInfoSequenceId(sequenceid);
   }
 
   /**
-   * Returns the latest table descriptor for the given table directly from the file system
-   * if it exists, bypassing the local cache.
-   * Returns null if it's not found.
+   * Returns the latest table descriptor for the given table directly from the file system if it
+   * exists, bypassing the local cache. Returns null if it's not found.
    */
-  public static TableDescriptor getTableDescriptorFromFs(FileSystem fs,
-    Path hbaseRootDir, TableName tableName) throws IOException {
+  public static TableDescriptor getTableDescriptorFromFs(FileSystem fs, Path hbaseRootDir,
+    TableName tableName) throws IOException {
     Path tableDir = HBCKFsUtils.getTableDir(hbaseRootDir, tableName);
     return getTableDescriptorFromFs(fs, tableDir);
   }
 
   /**
-   * Returns the latest table descriptor for the table located at the given directory
-   * directly from the file system if it exists.
+   * Returns the latest table descriptor for the table located at the given directory directly from
+   * the file system if it exists.
    * @throws TableInfoMissingException if there is no descriptor
    */
   public static TableDescriptor getTableDescriptorFromFs(FileSystem fs, Path tableDir)
@@ -273,7 +257,7 @@ public class HBCKFsTableDescriptors  {
   private static TableDescriptor readTableDescriptor(FileSystem fs, FileStatus status)
     throws IOException {
     int len = Ints.checkedCast(status.getLen());
-    byte [] content = new byte[len];
+    byte[] content = new byte[len];
     FSDataInputStream fsDataInputStream = fs.open(status.getPath());
     try {
       fsDataInputStream.readFully(content);
@@ -290,8 +274,7 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Deletes all the table descriptor files from the file system.
-   * Used in unit tests only.
+   * Deletes all the table descriptor files from the file system. Used in unit tests only.
    * @throws NotImplementedException if in read only mode
    */
   public void deleteTableDescriptorIfExists(TableName tableName) throws IOException {
@@ -301,12 +284,12 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Deletes files matching the table info file pattern within the given directory
-   * whose sequenceId is at most the given max sequenceId.
+   * Deletes files matching the table info file pattern within the given directory whose sequenceId
+   * is at most the given max sequenceId.
    */
   private static void deleteTableDescriptorFiles(FileSystem fs, Path dir, int maxSequenceId)
     throws IOException {
-    FileStatus [] status = HBCKFsUtils.listStatus(fs, dir, TABLEINFO_PATHFILTER);
+    FileStatus[] status = HBCKFsUtils.listStatus(fs, dir, TABLEINFO_PATHFILTER);
     for (FileStatus file : status) {
       Path path = file.getPath();
       int sequenceId = getTableInfoSequenceId(path);
@@ -322,30 +305,26 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Attempts to write a new table descriptor to the given table's directory.
-   * It first writes it to the .tmp dir then uses an atomic rename to move it into place.
-   * It begins at the currentSequenceId + 1 and tries 10 times to find a new sequence number
-   * not already in use.
+   * Attempts to write a new table descriptor to the given table's directory. It first writes it to
+   * the .tmp dir then uses an atomic rename to move it into place. It begins at the
+   * currentSequenceId + 1 and tries 10 times to find a new sequence number not already in use.
    * Removes the current descriptor file if passed in.
-   *
    * @return Descriptor file or null if we failed write.
    */
-  private static Path writeTableDescriptor(final FileSystem fs,
-                                           final TableDescriptor htd, final Path tableDir,
-                                           final FileStatus currentDescriptorFile)
-    throws IOException {
+  private static Path writeTableDescriptor(final FileSystem fs, final TableDescriptor htd,
+    final Path tableDir, final FileStatus currentDescriptorFile) throws IOException {
     // Get temporary dir into which we'll first write a file to avoid half-written file phenomenon.
     // This directory is never removed to avoid removing it out from under a concurrent writer.
     Path tmpTableDir = new Path(tableDir, TMP_DIR);
     Path tableInfoDir = new Path(tableDir, TABLEINFO_DIR);
 
-    // What is current sequenceid?  We read the current sequenceid from
-    // the current file.  After we read it, another thread could come in and
-    // compete with us writing out next version of file.  The below retries
+    // What is current sequenceid? We read the current sequenceid from
+    // the current file. After we read it, another thread could come in and
+    // compete with us writing out next version of file. The below retries
     // should help in this case some but its hard to do guarantees in face of
     // concurrent schema edits.
-    int currentSequenceId = currentDescriptorFile == null ? 0 :
-      getTableInfoSequenceId(currentDescriptorFile.getPath());
+    int currentSequenceId =
+      currentDescriptorFile == null ? 0 : getTableInfoSequenceId(currentDescriptorFile.getPath());
     int newSequenceId = currentSequenceId;
 
     // Put arbitrary upperbound on how often we retry
@@ -369,6 +348,11 @@ public class HBCKFsTableDescriptors  {
         }
         LOG.debug("Wrote into " + tableInfoDirPath);
       } catch (IOException ioe) {
+        // fail-fast and get out of retry loop as user does not have privilege to write to hdfs
+        // hence, no point in retrying
+        if (ioe instanceof AccessControlException) {
+          throw ioe;
+        }
         // Presume clash of names or something; go around again.
         LOG.debug("Failed write and/or rename; retrying", ioe);
         if (!HBCKFsUtils.deleteDirectory(fs, tempPath)) {
@@ -391,7 +375,7 @@ public class HBCKFsTableDescriptors  {
     FSDataOutputStream out = fs.create(p, false);
     try {
       // We used to write this file out as a serialized HTD Writable followed by two '\n's and then
-      // the toString version of HTD.  Now we just write out the pb serialization.
+      // the toString version of HTD. Now we just write out the pb serialization.
       out.write(TableDescriptorBuilder.toByteArray(htd));
     } finally {
       out.close();
@@ -399,10 +383,8 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Create new TableDescriptor in HDFS. Happens when we are creating table. If
-   * forceCreation is true then even if previous table descriptor is present it
-   * will be overwritten
-   *
+   * Create new TableDescriptor in HDFS. Happens when we are creating table. If forceCreation is
+   * true then even if previous table descriptor is present it will be overwritten
    * @return True if we successfully created file.
    */
   public boolean createTableDescriptor(TableDescriptor htd, boolean forceCreation)
@@ -412,18 +394,18 @@ public class HBCKFsTableDescriptors  {
   }
 
   /**
-   * Create a new TableDescriptor in HDFS in the specified table directory. Happens when we create
-   * a new table or snapshot a table.
-   * @param tableDir table directory under which we should write the file
-   * @param htd description of the table to write
+   * Create a new TableDescriptor in HDFS in the specified table directory. Happens when we create a
+   * new table or snapshot a table.
+   * @param tableDir      table directory under which we should write the file
+   * @param htd           description of the table to write
    * @param forceCreation if <tt>true</tt>,then even if previous table descriptor is present it will
-   *          be overwritten
+   *                      be overwritten
    * @return <tt>true</tt> if the we successfully created the file, <tt>false</tt> if the file
    *         already exists and we weren't forcing the descriptor creation.
    * @throws IOException if a filesystem error occurs
    */
-  public boolean createTableDescriptorForTableDirectory(Path tableDir,
-    TableDescriptor htd, boolean forceCreation) throws IOException {
+  public boolean createTableDescriptorForTableDirectory(Path tableDir, TableDescriptor htd,
+    boolean forceCreation) throws IOException {
     FileStatus status = getTableInfoPath(fs, tableDir);
     if (status != null) {
       LOG.debug("Current path=" + status.getPath());
@@ -439,7 +421,4 @@ public class HBCKFsTableDescriptors  {
     Path p = writeTableDescriptor(fs, htd, tableDir, status);
     return p != null;
   }
-
 }
-
-
