@@ -18,7 +18,6 @@
 package org.apache.hbase;
 
 import edu.umd.cs.findbugs.annotations.CheckForNull;
-
 import java.io.FileNotFoundException;
 import java.io.IOException;
 import java.util.ArrayList;
@@ -30,7 +29,6 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.Future;
 import java.util.regex.Pattern;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -48,8 +46,8 @@ import org.slf4j.LoggerFactory;
 import org.apache.hbase.thirdparty.com.google.common.collect.Iterators;
 
 /**
- * hbck's local version of the CommonFSUtils from the hbase repo
- * A Utility class to facilitate hbck2's access to tables/namespace dir structures.
+ * hbck's local version of the CommonFSUtils from the hbase repo A Utility class to facilitate
+ * hbck2's access to tables/namespace dir structures.
  */
 @InterfaceAudience.Private
 public final class HBCKFsUtils {
@@ -64,11 +62,8 @@ public final class HBCKFsUtils {
 
   /**
    * Returns the {@link org.apache.hadoop.fs.Path} object representing the table directory under
-   * path rootdir
-   *
-   * COPIED from CommonFSUtils.getTableDir
-   *
-   * @param rootdir qualified path of HBase root directory
+   * path rootdir COPIED from CommonFSUtils.getTableDir
+   * @param rootdir   qualified path of HBase root directory
    * @param tableName name of table
    * @return {@link org.apache.hadoop.fs.Path} for table
    */
@@ -78,27 +73,20 @@ public final class HBCKFsUtils {
   }
 
   /**
-   * Returns the {@link org.apache.hadoop.fs.Path} object representing
-   * the namespace directory under path rootdir
-   *
-   * COPIED from CommonFSUtils.getNamespaceDir
-   *
-   * @param rootdir qualified path of HBase root directory
+   * Returns the {@link org.apache.hadoop.fs.Path} object representing the namespace directory under
+   * path rootdir COPIED from CommonFSUtils.getNamespaceDir
+   * @param rootdir   qualified path of HBase root directory
    * @param namespace namespace name
    * @return {@link org.apache.hadoop.fs.Path} for table
    */
   public static Path getNamespaceDir(Path rootdir, final String namespace) {
-    return new Path(rootdir, new Path(HConstants.BASE_NAMESPACE_DIR,
-      new Path(namespace)));
+    return new Path(rootdir, new Path(HConstants.BASE_NAMESPACE_DIR, new Path(namespace)));
   }
 
   /**
-   *
    * COPIED from CommonFSUtils.getRootDir
-   *
    * @param c configuration
-   * @return {@link Path} to hbase root directory from
-   *     configuration as a qualified Path.
+   * @return {@link Path} to hbase root directory from configuration as a qualified Path.
    * @throws IOException e
    */
   public static Path getRootDir(final Configuration c) throws IOException {
@@ -117,15 +105,13 @@ public final class HBCKFsUtils {
   }
 
   /**
-   * Copy all files/subdirectories from source path to destination path.
-   *
-   * COPIED from FSUtils.copyFilesParallel
-   *
-   * @param srcFS FileSystem instance for the source path
-   * @param src source path
-   * @param dstFS FileSystem instance for the destination path
-   * @param dst destination path
-   * @param conf a valid hbase configuration object
+   * Copy all files/subdirectories from source path to destination path. COPIED from
+   * FSUtils.copyFilesParallel
+   * @param srcFS   FileSystem instance for the source path
+   * @param src     source path
+   * @param dstFS   FileSystem instance for the destination path
+   * @param dst     destination path
+   * @param conf    a valid hbase configuration object
    * @param threads number of threads to execute the copy
    * @return list of Path representing all items residing int the source path
    * @throws IOException e
@@ -171,26 +157,21 @@ public final class HBCKFsUtils {
     }
     return traversedPaths;
   }
+
   /*
-   *
-   * COPIED from CommonFSUtils.listStatus
-   *
-   * Calls fs.listStatus() and treats FileNotFoundException as non-fatal
-   * This accommodates differences between hadoop versions, where hadoop 1
-   * does not throw a FileNotFoundException, and return an empty FileStatus[]
-   * while Hadoop 2 will throw FileNotFoundException.
-   *
-   * Where possible, prefer FSUtils#listStatusWithStatusFilter(FileSystem,
+   * COPIED from CommonFSUtils.listStatus Calls fs.listStatus() and treats FileNotFoundException as
+   * non-fatal This accommodates differences between hadoop versions, where hadoop 1 does not throw
+   * a FileNotFoundException, and return an empty FileStatus[] while Hadoop 2 will throw
+   * FileNotFoundException. Where possible, prefer FSUtils#listStatusWithStatusFilter(FileSystem,
    * Path, FileStatusFilter) instead.
-   *
    * @param fs file system
    * @param dir directory
    * @param filter path filter
    * @return null if dir is empty or doesn't exist, otherwise FileStatus array
    */
-  public static FileStatus [] listStatus(final FileSystem fs,
-    final Path dir, final PathFilter filter) throws IOException {
-    FileStatus [] status = null;
+  public static FileStatus[] listStatus(final FileSystem fs, final Path dir,
+    final PathFilter filter) throws IOException {
+    FileStatus[] status = null;
     try {
       status = filter == null ? fs.listStatus(dir) : fs.listStatus(dir, filter);
     } catch (FileNotFoundException fnfe) {
@@ -206,13 +187,10 @@ public final class HBCKFsUtils {
   }
 
   /**
-   *
-   * COPIED from CommonFSUtils.delete
-   *
-   * Calls fs.delete() and returns the value returned by the fs.delete()
-   *
-   * @param fs must not be null
-   * @param path must not be null
+   * COPIED from CommonFSUtils.delete Calls fs.delete() and returns the value returned by the
+   * fs.delete()
+   * @param fs        must not be null
+   * @param path      must not be null
    * @param recursive delete tree rooted at path
    * @return the value returned by the fs.delete()
    * @throws IOException from underlying FileSystem
@@ -223,27 +201,20 @@ public final class HBCKFsUtils {
   }
 
   /**
-   *
-   * COPIED from CommonFSUtils.deleteDirectory
-   *
-   * Delete if exists.
-   * @param fs filesystem object
+   * COPIED from CommonFSUtils.deleteDirectory Delete if exists.
+   * @param fs  filesystem object
    * @param dir directory to delete
    * @return True if deleted <code>dir</code>
    * @throws IOException on IO errors
    */
-  public static boolean deleteDirectory(final FileSystem fs, final Path dir)
-    throws IOException {
+  public static boolean deleteDirectory(final FileSystem fs, final Path dir) throws IOException {
     return fs.exists(dir) && fs.delete(dir, true);
   }
 
   /**
-   *
-   * COPIED from FsUtils.getRegionDirs
-   *
-   * Given a particular table dir, return all the regiondirs inside it, excluding files such as
-   * .tableinfo
-   * @param fs A file system for the Path
+   * COPIED from FsUtils.getRegionDirs Given a particular table dir, return all the regiondirs
+   * inside it, excluding files such as .tableinfo
+   * @param fs       A file system for the Path
    * @param tableDir Path to a specific table directory &lt;hbase.rootdir&gt;/&lt;tabledir&gt;
    * @return List of paths to valid region directories in table dir.
    * @throws IOException on IO errors
@@ -256,7 +227,7 @@ public final class HBCKFsUtils {
       return new ArrayList<>();
     }
     List<Path> regionDirs = new ArrayList<>(rds.size());
-    for (FileStatus rdfs: rds) {
+    for (FileStatus rdfs : rds) {
       Path rdPath = rdfs.getPath();
       regionDirs.add(rdPath);
     }
@@ -264,22 +235,18 @@ public final class HBCKFsUtils {
   }
 
   /**
-   *
-   * COPIED from FsUtils.listStatusWithStatusFilter
-   *
-   * Calls fs.listStatus() and treats FileNotFoundException as non-fatal
-   * This accommodates differences between hadoop versions, where hadoop 1
-   * does not throw a FileNotFoundException, and return an empty FileStatus[]
-   * while Hadoop 2 will throw FileNotFoundException.
-   *
-   * @param fs file system
-   * @param dir directory
+   * COPIED from FsUtils.listStatusWithStatusFilter Calls fs.listStatus() and treats
+   * FileNotFoundException as non-fatal This accommodates differences between hadoop versions, where
+   * hadoop 1 does not throw a FileNotFoundException, and return an empty FileStatus[] while Hadoop
+   * 2 will throw FileNotFoundException.
+   * @param fs     file system
+   * @param dir    directory
    * @param filter file status filter
    * @return null if dir is empty or doesn't exist, otherwise FileStatus list
    */
   public static List<FileStatus> listStatusWithStatusFilter(final FileSystem fs, final Path dir,
     final HBCKFileStatusFilter filter) throws IOException {
-    FileStatus [] status = null;
+    FileStatus[] status = null;
     try {
       status = fs.listStatus(dir);
     } catch (FileNotFoundException fnfe) {
@@ -289,7 +256,7 @@ public final class HBCKFsUtils {
       }
     }
 
-    if (status == null || status.length < 1)  {
+    if (status == null || status.length < 1) {
       return null;
     }
 
@@ -306,17 +273,13 @@ public final class HBCKFsUtils {
   }
 
   /**
-   *
-   * COPIED from FsUtils.filterFileStatuses
-   *
-   * Filters FileStatuses in an array and returns a list
-   *
-   * @param input   An array of FileStatuses
-   * @param filter  A required filter to filter the array
-   * @return        A list of FileStatuses
+   * COPIED from FsUtils.filterFileStatuses Filters FileStatuses in an array and returns a list
+   * @param input  An array of FileStatuses
+   * @param filter A required filter to filter the array
+   * @return A list of FileStatuses
    */
   public static List<FileStatus> filterFileStatuses(FileStatus[] input,
-                                                    HBCKFileStatusFilter filter) {
+    HBCKFileStatusFilter filter) {
     if (input == null) {
       return null;
     }
@@ -324,17 +287,13 @@ public final class HBCKFsUtils {
   }
 
   /**
-   *
-   * COPIED from FsUtils.filterFileStatuses
-   *
-   * Filters FileStatuses in an iterator and returns a list
-   *
-   * @param input   An iterator of FileStatuses
-   * @param filter  A required filter to filter the array
-   * @return        A list of FileStatuses
+   * COPIED from FsUtils.filterFileStatuses Filters FileStatuses in an iterator and returns a list
+   * @param input  An iterator of FileStatuses
+   * @param filter A required filter to filter the array
+   * @return A list of FileStatuses
    */
   public static List<FileStatus> filterFileStatuses(Iterator<FileStatus> input,
-                                                    HBCKFileStatusFilter filter) {
+    HBCKFileStatusFilter filter) {
     if (input == null) {
       return null;
     }
@@ -348,13 +307,10 @@ public final class HBCKFsUtils {
     return results;
   }
 
-
   /**
-   *
-   * COPIED from FsUtils.FamilyDirFilter
-   *
-   * Filter for all dirs that are legal column family names.  This is generally used for colfam
-   * dirs &lt;hbase.rootdir&gt;/&lt;tabledir&gt;/&lt;regiondir&gt;/&lt;colfamdir&gt;.
+   * COPIED from FsUtils.FamilyDirFilter Filter for all dirs that are legal column family names.
+   * This is generally used for colfam dirs
+   * &lt;hbase.rootdir&gt;/&lt;tabledir&gt;/&lt;regiondir&gt;/&lt;colfamdir&gt;.
    */
   public static class FamilyDirFilter extends HBCKAbstractFileStatusFilter {
     final FileSystem fs;
@@ -377,17 +333,14 @@ public final class HBCKFsUtils {
         return isDirectory(fs, isDir, p);
       } catch (IOException ioe) {
         // Maybe the file was moved or the fs was disconnected.
-        LOG.warn("Skipping file " + p +" due to IOException", ioe);
+        LOG.warn("Skipping file " + p + " due to IOException", ioe);
         return false;
       }
     }
   }
 
   /**
-   *
-   * COPIED from FsUtils.RegionDirFilter
-   *
-   * Filter for all dirs that don't start with '.'
+   * COPIED from FsUtils.RegionDirFilter Filter for all dirs that don't start with '.'
    */
   public static class RegionDirFilter extends HBCKAbstractFileStatusFilter {
     // This pattern will accept 0.90+ style hex region dirs and older numeric region dir names.
@@ -408,7 +361,7 @@ public final class HBCKFsUtils {
         return isDirectory(fs, isDir, p);
       } catch (IOException ioe) {
         // Maybe the file was moved or the fs was disconnected.
-        LOG.warn("Skipping file " + p +" due to IOException", ioe);
+        LOG.warn("Skipping file " + p + " due to IOException", ioe);
         return false;
       }
     }
