@@ -30,7 +30,6 @@ import java.util.concurrent.ExecutionException;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.AtomicInteger;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.fs.FileStatus;
 import org.apache.hadoop.fs.FileSystem;
@@ -48,19 +47,15 @@ import org.apache.hadoop.hbase.util.FSUtils.HFileFilter;
 import org.apache.hadoop.hbase.util.FSUtils.RegionDirFilter;
 import org.apache.hbase.HBCKFsUtils;
 import org.apache.yetus.audience.InterfaceAudience;
-
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * This class marches through all of the region's hfiles and verifies that
- * they are all valid files. One just needs to instantiate the class, use
- * checkTables(List&lt;Path&gt;) and then retrieve the corrupted hfiles (and
- * quarantined files if in quarantining mode)
- *
- * The implementation currently parallelizes at the regionDir level.
- *
- * Copied over wholesale from hbase. Unaltered except for package and imports.
+ * This class marches through all of the region's hfiles and verifies that they are all valid files.
+ * One just needs to instantiate the class, use checkTables(List&lt;Path&gt;) and then retrieve the
+ * corrupted hfiles (and quarantined files if in quarantining mode) The implementation currently
+ * parallelizes at the regionDir level. Copied over wholesale from hbase. Unaltered except for
+ * package and imports.
  */
 @InterfaceAudience.Private
 public class HFileCorruptionChecker {
@@ -82,8 +77,8 @@ public class HFileCorruptionChecker {
   final AtomicInteger hfilesChecked = new AtomicInteger();
   final AtomicInteger mobFilesChecked = new AtomicInteger();
 
-  public HFileCorruptionChecker(Configuration conf, ExecutorService executor,
-      boolean quarantine) throws IOException {
+  public HFileCorruptionChecker(Configuration conf, ExecutorService executor, boolean quarantine)
+    throws IOException {
     this.conf = conf;
     this.fs = HBCKFsUtils.getRootDirFileSystem(conf);
     this.cacheConf = CacheConfig.DISABLED;
@@ -92,12 +87,8 @@ public class HFileCorruptionChecker {
   }
 
   /**
-   * Checks a path to see if it is a valid hfile.
-   *
-   * @param p
-   *          full Path to an HFile
-   * @throws IOException
-   *           This is a connectivity related exception
+   * Checks a path to see if it is a valid hfile. full Path to an HFile This is a connectivity
+   * related exception
    */
   protected void checkHFile(Path p) throws IOException {
     HFile.Reader r = null;
@@ -110,7 +101,7 @@ public class HFileCorruptionChecker {
         Path dest = createQuarantinePath(p);
         LOG.warn("Quarantining corrupt HFile " + p + " into " + dest);
         boolean success = fs.mkdirs(dest.getParent());
-        success = success ? fs.rename(p, dest): false;
+        success = success ? fs.rename(p, dest) : false;
         if (!success) {
           failures.add(p);
         } else {
@@ -130,12 +121,8 @@ public class HFileCorruptionChecker {
   }
 
   /**
-   * Given a path, generates a new path to where we move a corrupted hfile (bad
-   * trailer, no trailer).
-   *
-   * @param hFile
-   *          Path to a corrupt hfile (assumes that it is HBASE_DIR/ table
-   *          /region/cf/file)
+   * Given a path, generates a new path to where we move a corrupted hfile (bad trailer, no
+   * trailer). Path to a corrupt hfile (assumes that it is HBASE_DIR/ table /region/cf/file)
    * @return path to where corrupted files are stored. This should be
    *         HBASE_DIR/.corrupt/table/region/cf/file.
    */
@@ -166,8 +153,8 @@ public class HFileCorruptionChecker {
       statuses = fs.listStatus(cfDir); // use same filter as scanner.
     } catch (FileNotFoundException fnfe) {
       // Hadoop 0.23+ listStatus semantics throws an exception if the path does not exist.
-      LOG.warn("Colfam Directory " + cfDir +
-          " does not exist.  Likely due to concurrent split/compaction. Skipping.");
+      LOG.warn("Colfam Directory " + cfDir
+        + " does not exist.  Likely due to concurrent split/compaction. Skipping.");
       missing.add(cfDir);
       return;
     }
@@ -175,8 +162,8 @@ public class HFileCorruptionChecker {
     List<FileStatus> hfs = FSUtils.filterFileStatuses(statuses, new HFileFilter(fs));
     // Hadoop 1.0 listStatus does not throw an exception if the path does not exist.
     if (hfs.isEmpty() && !fs.exists(cfDir)) {
-      LOG.warn("Colfam Directory " + cfDir +
-          " does not exist.  Likely due to concurrent split/compaction. Skipping.");
+      LOG.warn("Colfam Directory " + cfDir
+        + " does not exist.  Likely due to concurrent split/compaction. Skipping.");
       missing.add(cfDir);
       return;
     }
@@ -195,8 +182,8 @@ public class HFileCorruptionChecker {
       statuses = fs.listStatus(cfDir); // use same filter as scanner.
     } catch (FileNotFoundException fnfe) {
       // Hadoop 0.23+ listStatus semantics throws an exception if the path does not exist.
-      LOG.warn("Mob colfam Directory " + cfDir +
-          " does not exist.  Likely the table is deleted. Skipping.");
+      LOG.warn("Mob colfam Directory " + cfDir
+        + " does not exist.  Likely the table is deleted. Skipping.");
       missedMobFiles.add(cfDir);
       return;
     }
@@ -204,8 +191,8 @@ public class HFileCorruptionChecker {
     List<FileStatus> hfs = FSUtils.filterFileStatuses(statuses, new HFileFilter(fs));
     // Hadoop 1.0 listStatus does not throw an exception if the path does not exist.
     if (hfs.isEmpty() && !fs.exists(cfDir)) {
-      LOG.warn("Mob colfam Directory " + cfDir +
-          " does not exist.  Likely the table is deleted. Skipping.");
+      LOG.warn("Mob colfam Directory " + cfDir
+        + " does not exist.  Likely the table is deleted. Skipping.");
       missedMobFiles.add(cfDir);
       return;
     }
@@ -216,12 +203,8 @@ public class HFileCorruptionChecker {
   }
 
   /**
-   * Checks a path to see if it is a valid mob file.
-   *
-   * @param p
-   *          full Path to a mob file.
-   * @throws IOException
-   *           This is a connectivity related exception
+   * Checks a path to see if it is a valid mob file. full Path to a mob file. This is a connectivity
+   * related exception
    */
   protected void checkMobFile(Path p) throws IOException {
     HFile.Reader r = null;
@@ -234,7 +217,7 @@ public class HFileCorruptionChecker {
         Path dest = createQuarantinePath(p);
         LOG.warn("Quarantining corrupt mob file " + p + " into " + dest);
         boolean success = fs.mkdirs(dest.getParent());
-        success = success ? fs.rename(p, dest): false;
+        success = success ? fs.rename(p, dest) : false;
         if (!success) {
           failureMobFiles.add(p);
         } else {
@@ -265,16 +248,16 @@ public class HFileCorruptionChecker {
       hfs = fs.listStatus(regionDir, new FamilyDirFilter(fs));
     } catch (FileNotFoundException fnfe) {
       // Hadoop 0.23+ listStatus semantics throws an exception if the path does not exist.
-      LOG.warn("Mob directory " + regionDir
-        + " does not exist.  Likely the table is deleted. Skipping.");
+      LOG.warn(
+        "Mob directory " + regionDir + " does not exist.  Likely the table is deleted. Skipping.");
       missedMobFiles.add(regionDir);
       return;
     }
 
     // Hadoop 1.0 listStatus does not throw an exception if the path does not exist.
     if (hfs.length == 0 && !fs.exists(regionDir)) {
-      LOG.warn("Mob directory " + regionDir
-        + " does not exist.  Likely the table is deleted. Skipping.");
+      LOG.warn(
+        "Mob directory " + regionDir + " does not exist.  Likely the table is deleted. Skipping.");
       missedMobFiles.add(regionDir);
       return;
     }
@@ -293,8 +276,8 @@ public class HFileCorruptionChecker {
       statuses = fs.listStatus(regionDir);
     } catch (FileNotFoundException fnfe) {
       // Hadoop 0.23+ listStatus semantics throws an exception if the path does not exist.
-      LOG.warn("Region Directory " + regionDir +
-          " does not exist.  Likely due to concurrent split/compaction. Skipping.");
+      LOG.warn("Region Directory " + regionDir
+        + " does not exist.  Likely due to concurrent split/compaction. Skipping.");
       missing.add(regionDir);
       return;
     }
@@ -302,8 +285,8 @@ public class HFileCorruptionChecker {
     List<FileStatus> cfs = FSUtils.filterFileStatuses(statuses, new FamilyDirFilter(fs));
     // Hadoop 1.0 listStatus does not throw an exception if the path does not exist.
     if (cfs.isEmpty() && !fs.exists(regionDir)) {
-      LOG.warn("Region Directory " + regionDir +
-          " does not exist.  Likely due to concurrent split/compaction. Skipping.");
+      LOG.warn("Region Directory " + regionDir
+        + " does not exist.  Likely due to concurrent split/compaction. Skipping.");
       missing.add(regionDir);
       return;
     }
@@ -319,11 +302,11 @@ public class HFileCorruptionChecker {
    */
   void checkTableDir(Path tableDir) throws IOException {
     List<FileStatus> rds =
-        FSUtils.listStatusWithStatusFilter(fs, tableDir, new RegionDirFilter(fs));
+      FSUtils.listStatusWithStatusFilter(fs, tableDir, new RegionDirFilter(fs));
     if (rds == null) {
       if (!fs.exists(tableDir)) {
-        LOG.warn("Table Directory " + tableDir +
-            " does not exist.  Likely due to concurrent delete. Skipping.");
+        LOG.warn("Table Directory " + tableDir
+          + " does not exist.  Likely due to concurrent delete. Skipping.");
         missing.add(tableDir);
       }
       return;
@@ -355,8 +338,8 @@ public class HFileCorruptionChecker {
       try {
         f.get();
       } catch (ExecutionException e) {
-        LOG.warn("Failed to quarantine an HFile in regiondir "
-            + rdcs.get(i).regionDir, e.getCause());
+        LOG.warn("Failed to quarantine an HFile in regiondir " + rdcs.get(i).regionDir,
+          e.getCause());
         // rethrow IOExceptions
         if (e.getCause() instanceof IOException) {
           throw (IOException) e.getCause();
@@ -380,8 +363,8 @@ public class HFileCorruptionChecker {
   }
 
   /**
-   * An individual work item for parallelized regiondir processing. This is
-   * intentionally an inner class so it can use the shared error sets and fs.
+   * An individual work item for parallelized regiondir processing. This is intentionally an inner
+   * class so it can use the shared error sets and fs.
    */
   private class RegionDirChecker implements Callable<Void> {
     final Path regionDir;
@@ -398,8 +381,8 @@ public class HFileCorruptionChecker {
   }
 
   /**
-   * An individual work item for parallelized mob dir processing. This is
-   * intentionally an inner class so it can use the shared error sets and fs.
+   * An individual work item for parallelized mob dir processing. This is intentionally an inner
+   * class so it can use the shared error sets and fs.
    */
   private class MobRegionDirChecker extends RegionDirChecker {
 
@@ -434,73 +417,57 @@ public class HFileCorruptionChecker {
     }
   }
 
-  /**
-   * @return the set of check failure file paths after checkTables is called.
-   */
+  /** Returns the set of check failure file paths after checkTables is called. */
   public Collection<Path> getFailures() {
     return new HashSet<>(failures);
   }
 
-  /**
-   * @return the set of corrupted file paths after checkTables is called.
-   */
+  /** Returns the set of corrupted file paths after checkTables is called. */
   public Collection<Path> getCorrupted() {
     return new HashSet<>(corrupted);
   }
 
-  /**
-   * @return number of hfiles checked in the last HfileCorruptionChecker run
-   */
+  /** Returns number of hfiles checked in the last HfileCorruptionChecker run */
   public int getHFilesChecked() {
     return hfilesChecked.get();
   }
 
-  /**
-   * @return the set of successfully quarantined paths after checkTables is called.
-   */
+  /** Returns the set of successfully quarantined paths after checkTables is called. */
   public Collection<Path> getQuarantined() {
     return new HashSet<>(quarantined);
   }
 
   /**
-   * @return the set of paths that were missing.  Likely due to deletion/moves from
-   *   compaction or flushes.
+   * @return the set of paths that were missing. Likely due to deletion/moves from compaction or
+   *         flushes.
    */
   public Collection<Path> getMissing() {
     return new HashSet<>(missing);
   }
 
-  /**
-   * @return the set of check failure mob file paths after checkTables is called.
-   */
+  /** Returns the set of check failure mob file paths after checkTables is called. */
   public Collection<Path> getFailureMobFiles() {
     return new HashSet<>(failureMobFiles);
   }
 
-  /**
-   * @return the set of corrupted mob file paths after checkTables is called.
-   */
+  /** Returns the set of corrupted mob file paths after checkTables is called. */
   public Collection<Path> getCorruptedMobFiles() {
     return new HashSet<>(corruptedMobFiles);
   }
 
-  /**
-   * @return number of mob files checked in the last HfileCorruptionChecker run
-   */
+  /** Returns number of mob files checked in the last HfileCorruptionChecker run */
   public int getMobFilesChecked() {
     return mobFilesChecked.get();
   }
 
-  /**
-   * @return the set of successfully quarantined paths after checkTables is called.
-   */
+  /** Returns the set of successfully quarantined paths after checkTables is called. */
   public Collection<Path> getQuarantinedMobFiles() {
     return new HashSet<>(quarantinedMobFiles);
   }
 
   /**
-   * @return the set of paths that were missing.  Likely due to table deletion or deletion/moves
-   *   from compaction.
+   * @return the set of paths that were missing. Likely due to table deletion or deletion/moves from
+   *         compaction.
    */
   public Collection<Path> getMissedMobFiles() {
     return new HashSet<>(missedMobFiles);
@@ -528,8 +495,7 @@ public class HFileCorruptionChecker {
     }
 
     String initialState = (corrupted.isEmpty()) ? "OK" : "CORRUPTED";
-    String fixedState = (corrupted.size() == quarantined.size()) ? "OK"
-        : "CORRUPTED";
+    String fixedState = (corrupted.size() == quarantined.size()) ? "OK" : "CORRUPTED";
 
     if (inQuarantineMode) {
       out.print("HFile Summary: " + initialState + " => " + fixedState);
@@ -555,8 +521,8 @@ public class HFileCorruptionChecker {
       out.print("      " + mq);
     }
     String initialMobState = (corruptedMobFiles.isEmpty()) ? "OK" : "CORRUPTED";
-    String fixedMobState = (corruptedMobFiles.size() == quarantinedMobFiles.size()) ? "OK"
-        : "CORRUPTED";
+    String fixedMobState =
+      (corruptedMobFiles.size() == quarantinedMobFiles.size()) ? "OK" : "CORRUPTED";
 
     if (inQuarantineMode) {
       out.print("MOB summary: " + initialMobState + " => " + fixedMobState);
