@@ -30,7 +30,6 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.Future;
 import java.util.concurrent.atomic.LongAdder;
-
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.conf.Configured;
 import org.apache.hadoop.fs.FileStatus;
@@ -61,8 +60,8 @@ import org.slf4j.LoggerFactory;
 
 /**
  * HBase maintenance tool for merging regions of a specific table, until a target number of regions
- * for the table is reached, or no more merges can complete due to limit in resulting merged
- * region size.
+ * for the table is reached, or no more merges can complete due to limit in resulting merged region
+ * size.
  */
 public class RegionsMerger extends Configured implements org.apache.hadoop.util.Tool {
 
@@ -81,13 +80,13 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
     this.conf = conf;
     Path basePath = new Path(conf.get(HConstants.HBASE_DIR));
     fs = basePath.getFileSystem(conf);
-    resultSizeThreshold = this.conf.getDouble(RESULTING_REGION_UPPER_MARK, 0.9) *
-      this.conf.getLong(HConstants.HREGION_MAX_FILESIZE, HConstants.DEFAULT_MAX_FILE_SIZE);
+    resultSizeThreshold = this.conf.getDouble(RESULTING_REGION_UPPER_MARK, 0.9)
+      * this.conf.getLong(HConstants.HREGION_MAX_FILESIZE, HConstants.DEFAULT_MAX_FILE_SIZE);
     sleepBetweenCycles = this.conf.getInt(SLEEP, 2000);
     this.maxRoundsStuck = this.conf.getInt(MAX_ROUNDS_IDLE, 10);
   }
 
-  private Path getTablePath(TableName table){
+  private Path getTablePath(TableName table) {
     Path basePath = new Path(conf.get(HConstants.HBASE_DIR));
     basePath = new Path(basePath, "data");
     Path tablePath = new Path(basePath, table.getNamespaceAsString());
@@ -97,10 +96,10 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
   private long sumSizeInFS(Path parentPath) throws IOException {
     long size = 0;
     FileStatus[] files = this.fs.listStatus(parentPath);
-    for(FileStatus f : files) {
-      if(f.isFile()) {
+    for (FileStatus f : files) {
+      if (f.isFile()) {
         size += f.getLen();
-      } else if(f.isDirectory()) {
+      } else if (f.isDirectory()) {
         size += sumSizeInFS(f.getPath());
       }
     }
@@ -111,17 +110,17 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
     List<RegionInfo> regions = new ArrayList<>();
     Table metaTbl = connection.getTable(META_TABLE_NAME);
     String tblName = table.getNameAsString();
-    RowFilter rowFilter = new RowFilter(CompareOperator.EQUAL,
-      new SubstringComparator(tblName+","));
-    SingleColumnValueFilter colFilter = new SingleColumnValueFilter(CATALOG_FAMILY,
-      STATE_QUALIFIER, CompareOperator.EQUAL, Bytes.toBytes("OPEN"));
+    RowFilter rowFilter =
+      new RowFilter(CompareOperator.EQUAL, new SubstringComparator(tblName + ","));
+    SingleColumnValueFilter colFilter = new SingleColumnValueFilter(CATALOG_FAMILY, STATE_QUALIFIER,
+      CompareOperator.EQUAL, Bytes.toBytes("OPEN"));
     colFilter.setFilterIfMissing(true);
     Scan scan = new Scan();
     FilterList filter = new FilterList(FilterList.Operator.MUST_PASS_ALL);
     filter.addFilter(rowFilter);
     filter.addFilter(colFilter);
     scan.setFilter(filter);
-    try(ResultScanner rs = metaTbl.getScanner(scan)){
+    try (ResultScanner rs = metaTbl.getScanner(scan)) {
       Result r;
       while ((r = rs.next()) != null) {
         RegionInfo region = RegionInfo.parseFrom(r.getValue(CATALOG_FAMILY, REGIONINFO_QUALIFIER));
@@ -132,12 +131,13 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
   }
 
   private boolean canMerge(Path path, RegionInfo region1, RegionInfo region2,
-      Collection<Pair<RegionInfo, RegionInfo>> alreadyMerging) throws IOException {
-    if(alreadyMerging.stream().anyMatch(regionPair ->
-        region1.equals(regionPair.getFirst()) ||
-        region2.equals(regionPair.getFirst()) ||
-        region1.equals(regionPair.getSecond()) ||
-        region2.equals(regionPair.getSecond()))){
+    Collection<Pair<RegionInfo, RegionInfo>> alreadyMerging) throws IOException {
+    if (
+      alreadyMerging.stream()
+        .anyMatch(regionPair -> region1.equals(regionPair.getFirst())
+          || region2.equals(regionPair.getFirst()) || region1.equals(regionPair.getSecond())
+          || region2.equals(regionPair.getSecond()))
+    ) {
       return false;
     }
     if (RegionInfo.areAdjacent(region1, region2)) {
@@ -145,17 +145,16 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
       long size2 = sumSizeInFS(new Path(path, region2.getEncodedName()));
       boolean mergeable = (resultSizeThreshold > (size1 + size2));
       if (!mergeable) {
-        LOG.warn("Not merging regions {} and {} because resulting region size would get close to " +
-            "the {} limit. {} total size: {}; {} total size:{}", region1.getEncodedName(),
-          region2.getEncodedName(), resultSizeThreshold, region1.getEncodedName(), size1,
-          region2.getEncodedName(), size2);
+        LOG.warn(
+          "Not merging regions {} and {} because resulting region size would get close to "
+            + "the {} limit. {} total size: {}; {} total size:{}",
+          region1.getEncodedName(), region2.getEncodedName(), resultSizeThreshold,
+          region1.getEncodedName(), size1, region2.getEncodedName(), size2);
       }
       return mergeable;
     } else {
-      LOG.warn(
-        "WARNING: Can't merge regions {} and {} because those are not adjacent.",
-        region1.getEncodedName(),
-        region2.getEncodedName());
+      LOG.warn("WARNING: Can't merge regions {} and {} because those are not adjacent.",
+        region1.getEncodedName(), region2.getEncodedName());
       return false;
     }
   }
@@ -166,7 +165,7 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
     get.addFamily(HConstants.CATALOG_FAMILY);
     Result r = meta.get(get);
     boolean result = HBCKMetaTableAccessor.getMergeRegions(r.rawCells()) != null;
-    if(result){
+    if (result) {
       LOG.warn("Region {} has an existing merge qualifier and can't be merged until for now. \n "
         + "RegionsMerger will skip this region until merge qualifier is cleaned away. \n "
         + "Consider major compact this region.", region.getEncodedName());
@@ -177,11 +176,11 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
   public void mergeRegions(String tblName, int targetRegions) throws Exception {
     TableName table = TableName.valueOf(tblName);
     Path tableDir = getTablePath(table);
-    try(Connection conn = ConnectionFactory.createConnection(conf)) {
+    try (Connection conn = ConnectionFactory.createConnection(conf)) {
       Admin admin = conn.getAdmin();
       LongAdder counter = new LongAdder();
       LongAdder lastTimeProgessed = new LongAdder();
-      //need to get all regions for the table, regardless of region state
+      // need to get all regions for the table, regardless of region state
       List<RegionInfo> regions = admin.getRegions(table);
       Map<Future, Pair<RegionInfo, RegionInfo>> regionsMerging = new ConcurrentHashMap<>();
       long roundsNoProgress = 0;
@@ -189,17 +188,20 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
         LOG.info("Iteration: {}", counter);
         RegionInfo previous = null;
         int regionSize = regions.size();
-        LOG.info("Attempting to merge {} regions to reach the target {} ...", regionSize, targetRegions);
-        //to request merge, regions must be OPEN, though
+        LOG.info("Attempting to merge {} regions to reach the target {} ...", regionSize,
+          targetRegions);
+        // to request merge, regions must be OPEN, though
         regions = getOpenRegions(conn, table);
         for (RegionInfo current : regions) {
           if (!current.isSplit()) {
-            if (previous != null && canMerge(tableDir, previous, current, regionsMerging.values())) {
-              //Before submitting a merge request, we need to check if any of the region candidates
-              //still have merge references from previous cycle
+            if (
+              previous != null && canMerge(tableDir, previous, current, regionsMerging.values())
+            ) {
+              // Before submitting a merge request, we need to check if any of the region candidates
+              // still have merge references from previous cycle
               boolean hasMergeRef =
                 hasPreviousMergeRef(conn, previous) || hasPreviousMergeRef(conn, current);
-              if(!hasMergeRef) {
+              if (!hasMergeRef) {
                 Future f = admin.mergeRegionsAsync(current.getEncodedNameAsBytes(),
                   previous.getEncodedNameAsBytes(), true);
                 Pair<RegionInfo, RegionInfo> regionPair = new Pair<>(previous, current);
@@ -215,36 +217,33 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
             } else {
               previous = current;
             }
-          }
-          else{
+          } else {
             LOG.debug("Skipping split region: {}", current.getEncodedName());
           }
         }
         counter.increment();
-        LOG.info("Sleeping for {} seconds before next iteration...", (sleepBetweenCycles/1000));
+        LOG.info("Sleeping for {} seconds before next iteration...", (sleepBetweenCycles / 1000));
         Thread.sleep(sleepBetweenCycles);
-        regionsMerging.forEach((f, currentPair)-> {
+        regionsMerging.forEach((f, currentPair) -> {
           if (f.isDone()) {
-            LOG.info("Merged regions {} and {} together.",
-              currentPair.getFirst().getEncodedName(),
+            LOG.info("Merged regions {} and {} together.", currentPair.getFirst().getEncodedName(),
               currentPair.getSecond().getEncodedName());
             regionsMerging.remove(f);
             lastTimeProgessed.reset();
             lastTimeProgessed.add(counter.longValue());
           } else {
-            LOG.warn("Merge of regions {} and {} isn't completed yet.",
-              currentPair.getFirst(),
+            LOG.warn("Merge of regions {} and {} isn't completed yet.", currentPair.getFirst(),
               currentPair.getSecond());
           }
         });
         roundsNoProgress = counter.longValue() - lastTimeProgessed.longValue();
-        if(roundsNoProgress == this.maxRoundsStuck){
+        if (roundsNoProgress == this.maxRoundsStuck) {
           LOG.warn("Reached {} iterations without progressing with new merges. Aborting...",
             roundsNoProgress);
           break;
         }
 
-        //again, get all regions, regardless of the state,
+        // again, get all regions, regardless of the state,
         // in order to avoid breaking the loop prematurely
         regions = admin.getRegions(table);
       }
@@ -253,21 +252,21 @@ public class RegionsMerger extends Configured implements org.apache.hadoop.util.
 
   @Override
   public int run(String[] args) {
-    if(args.length!=2){
-      LOG.error("Wrong number of arguments. "
-        + "Arguments are: <TABLE_NAME> <TARGET_NUMBER_OF_REGIONS>");
+    if (args.length != 2) {
+      LOG.error(
+        "Wrong number of arguments. " + "Arguments are: <TABLE_NAME> <TARGET_NUMBER_OF_REGIONS>");
       return 1;
     }
     try {
       this.mergeRegions(args[0], Integer.parseInt(args[1]));
-    } catch(Exception e){
+    } catch (Exception e) {
       LOG.error("Merging regions failed:", e);
       return 2;
     }
     return 0;
   }
 
-  public static void main(String [] args) throws Exception {
+  public static void main(String[] args) throws Exception {
     Configuration conf = HBaseConfiguration.create();
     int errCode = ToolRunner.run(new RegionsMerger(conf), args);
     if (errCode != 0) {
